import { declarePreset } from '@babel/helper-plugin-utils';
import transformFlowStripTypes from '@babel/plugin-transform-flow-strip-types';
import { OptionValidator } from '@babel/helper-validator-option';

const v = new OptionValidator("@babel/preset-flow");
function normalizeOptions(options = {}) {
  let {
    all,
    ignoreExtensions
  } = options;
  {
    v.invariant(!("allowDeclareFields" in options), `Since Babel 8, \`declare property: A\` is always supported, and the "allowDeclareFields" option is no longer available. Please remove it from your config.`);
    const TopLevelOptions = {
      all: "all",
      ignoreExtensions: "ignoreExtensions"
    };
    v.validateTopLevelOptions(options, TopLevelOptions);
    all = v.validateBooleanOption(TopLevelOptions.all, all);
    ignoreExtensions = v.validateBooleanOption(TopLevelOptions.ignoreExtensions, ignoreExtensions);
    return {
      all,
      ignoreExtensions
    };
  }
}

var index = declarePreset((api, opts) => {
  api.assertVersion(7);
  const {
    all,
    allowDeclareFields,
    ignoreExtensions = false
  } = normalizeOptions(opts);
  const flowPlugin = [transformFlowStripTypes, {
    all,
    allowDeclareFields
  }];
  if (ignoreExtensions) {
    return {
      plugins: [flowPlugin]
    };
  }
  {
    return {
      overrides: [{
        test: filename => filename == null || !/\.tsx?$/.test(filename),
        plugins: [flowPlugin]
      }]
    };
  }
});

export { index as default };
//# sourceMappingURL=index.js.map
